@@ -17,7 +17,7 @@ def compute_grid_prices( * ,
         initial_price = round(center_price - gap, price_decimal_places)
     prices = []
     for i in range(order_count):
-        is_even = bool(i % 2)
+        is_even = not bool(i % 2)
         multiplier = (-1 * (i // 2)) if is_even else (2 + i // 2)
         prices.append(initial_price + gap * multiplier)
     return prices
